package com.tiangua.star.util;

import org.apache.http.HttpEntity;
import org.apache.http.client.methods.*;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.Map;

public class HttpClientUtil {

    /**
     * 发送 GET 请求
     *
     * @param url 请求的 URL
     * @return 响应内容
     * @throws IOException 如果发生 I/O 异常
     */
    public static String sendGet(String url) throws IOException {
        try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
            HttpGet httpGet = new HttpGet(url);
            return executeRequest(httpClient, httpGet);
        }
    }

    /**
     * 发送 POST 请求，参数以 JSON 格式发送
     *
     * @param url        请求的 URL
     * @param jsonParams JSON 格式的字符串参数
     * @return 响应内容
     * @throws IOException 如果发生 I/O 异常
     */
    public static String sendPost(String url, String jsonParams) throws IOException {
        try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
            HttpPost httpPost = new HttpPost(url);
            if (jsonParams != null) {
                StringEntity entity = new StringEntity(jsonParams, ContentType.APPLICATION_JSON);
                httpPost.setEntity(entity);
            }
            return executeRequest(httpClient, httpPost);
        }
    }

    /**
     * 执行 HTTP 请求并返回响应内容
     *
     * @param httpClient  HttpClient 实例
     * @param httpRequest HTTP 请求对象
     * @return 响应内容
     * @throws IOException 如果发生 I/O 异常
     */
    private static String executeRequest(CloseableHttpClient httpClient, HttpUriRequest httpRequest) throws IOException {
        try (CloseableHttpResponse response = httpClient.execute(httpRequest)) {
            HttpEntity entity = response.getEntity();
            return entity != null ? EntityUtils.toString(entity, StandardCharsets.UTF_8) : null;
        }
    }
}
